# CHANGELOG

## 1.0.6 - 2022-03-28

* fixed issue with kwargs from BasicRestEndpoint persisting through multiple tests

## 1.0.0 - 2022-02-04
* Added --mock option to mock requests for the tests.
* restructured the code so that it can be imported into plugins more easily.

## 0.1.0 - 2022-01-27
* First release.


